﻿using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Drawing;
using System.Drawing.Text;
using System.Windows.Forms;

namespace MemDataTable_CS
{
    public class GroupByRowMultilineCreationFilter : IUIElementCreationFilter
    {
        void IUIElementCreationFilter.AfterCreateChildElements(UIElement parent)
        {
            var groupByRowDescriptionUIElement = parent as GroupByRowDescriptionUIElement;
            if (null != groupByRowDescriptionUIElement)
            {
                var dependentTextUIElement = parent.GetDescendant(typeof(DependentTextUIElement)) as DependentTextUIElement;
                if (null != dependentTextUIElement &&
                    false == (dependentTextUIElement is MultiLineDependentTextUIElement))
                {
                    MultiLineDependentTextUIElement multiLineDependentTextUIElement = new MultiLineDependentTextUIElement(parent, dependentTextUIElement.Provider);
                    multiLineDependentTextUIElement.Rect = dependentTextUIElement.Rect;
                    parent.ChildElements.Remove(dependentTextUIElement);
                    parent.ChildElements.Add(multiLineDependentTextUIElement);
                }
            }
        }

        bool IUIElementCreationFilter.BeforeCreateChildElements(UIElement parent)
        {
            // Do nothing.
            return false;
        }
    }

    public class MultiLineDependentTextUIElement : DependentTextUIElement,
        IUIElementTextProvider
    {
        private IUIElementTextProvider originalProvider;

        public MultiLineDependentTextUIElement(UIElement parent, IUIElementTextProvider provider) : base(parent, provider)
        {
            this.originalProvider = provider;

            InitProvider(this);
        }

        public void AdjustTextDisplayRect(DependentTextUIElement element, ref Rectangle displayRect)
        {
            this.originalProvider.AdjustTextDisplayRect(element, ref displayRect);
        }

        public Border3DSide GetBorderSides(UIElement element)
        {
            return this.originalProvider.GetBorderSides(element);
        }

        public UIElementBorderStyle GetBorderStyle(UIElement element)
        {
            return this.originalProvider.GetBorderStyle(element);
        }

        public Cursor GetCursor(UIElement element)
        {
            return this.originalProvider.GetCursor(element);
        }

        public string GetText(DependentTextUIElement element)
        {
            return this.originalProvider.GetText(element);
        }

        public void GetTextPadding(DependentTextUIElement element, ref Size padding)
        {
            this.originalProvider.GetTextPadding(element, ref padding);
        }

        public void InitElementAppearance(UIElement element, ref AppearanceData appearance, ref AppearancePropFlags requestedProps)
        {
            this.originalProvider.InitElementAppearance(element, ref appearance, ref requestedProps);
        }

        public bool IsMultiLine(DependentTextUIElement element)
        {
            //return this.originalProvider.IsMultiLine(element);
            return true;
        }

        public bool IsVertical(DependentTextUIElement element)
        {
            return this.originalProvider.IsVertical(element);
        }

        HotkeyPrefix IUIElementTextProvider.HotkeyPrefix(DependentTextUIElement element)
        {
            return this.originalProvider.HotkeyPrefix(element);
        }

        bool IUIElementTextProvider.WrapText(DependentTextUIElement element)
        {
            //return this.originalProvider.WrapText(element);
            return true;
        }
    }
}
